#
# Please do not update/rebuild/touch this package before asking first
# to mikala and/or neoclust and/or daviddavid
# This package is part of the KDE Stack.
# Also, make sure to rebuild openldap after updating this package.
#

%define rel 1

# The files themselves are in several subdirectories and need to be prefixed wit this.

%global archive_path libraries/lib%{name}

# Archive from GitLab tag contains the commit hash in the top-level directory name
%global commit_hash 3c9aa9df8497ad977e0f91347f0626f5d53c9ab7

Summary:        Memory-mapped key-value database
Name:           lmdb
Version:        0.9.27
Release:        %mkrel %{rel}
License:        GPLv2+
Group:          System/Base
URL:            http://symas.com/mdb/
Source0:        https://git.openldap.org/openldap/openldap/-/archive/LMDB_%{version}.tar.gz
Source1:        lmdb.pc.in
# Patch description in the corresponding file
Patch0:         lmdb-make.patch
# Fedora S390 build-time hack only:
#Patch1: lmdb-s390-check.patch

BuildRequires:  doxygen

%description
LMDB is an ultra-fast, ultra-compact key-value embedded data
store developed by for the OpenLDAP Project. By using memory-mapped files,
it provides the read performance of a pure in-memory database while still
offering the persistence of standard disk-based databases, and is only limited
to the size of the virtual address space.

%files
%{_bindir}/*
%{_mandir}/man1/*

#--------------------------------------------------------------------

%define major 0
%define liblmdb %mklibname lmdb %{major}

%package -n %{liblmdb}
Summary:        Memory-mapped key-value database
Group:          System/Libraries

%description -n %{liblmdb}
LMDB is an ultra-fast, ultra-compact key-value embedded data
store developed by for the OpenLDAP Project. By using memory-mapped files,
it provides the read performance of a pure in-memory database while still
offering the persistence of standard disk-based databases, and is only limited
to the size of the virtual address space.

%files -n %{liblmdb}
%{_libdir}/liblmdb.so.%{major}{,.*}

#--------------------------------------------------------------------

%define lmdb_devel %mklibname lmdb -d

%package -n %{lmdb_devel}
Summary:        Devel stuff for %{name}
Group:          Development/KDE and Qt
Requires:       %{liblmdb} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{lmdb_devel}
This package contains header files needed if you wish to build applications
based on %{name}.

%files -n %{lmdb_devel}
%{_libdir}/liblmdb.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*.h

#--------------------------------------------------------------------


%prep
%autosetup -p1 -n openldap-LMDB_%{version}-%{commit_hash}

%build
pushd %{archive_path}
%set_build_flags
%make_build XCFLAGS="%{build_cflags}"
# Build doxygen documentation
doxygen
# remove unpackaged files
rm -f Doxyfile
rm -rf man # Doxygen generated manpages
popd

%install
pushd %{archive_path}
# make install expects existing directory tree
mkdir -m 0755 -p %{buildroot}{%{_bindir},%{_includedir}}
mkdir -m 0755 -p %{buildroot}{%{_libdir}/pkgconfig,%{_mandir}/man1}

%make_install prefix=%{_prefix} libdir=%{_libdir} mandir=%{_mandir}
popd

# Install pkgconfig file
sed -e 's:@PREFIX@:%{_prefix}:g' \
    -e 's:@EXEC_PREFIX@:%{_exec_prefix}:g' \
    -e 's:@LIBDIR@:%{_libdir}:g' \
    -e 's:@INCLUDEDIR@:%{_includedir}:g' \
    -e 's:@PACKAGE_VERSION@:%{version}:g' \
    %{SOURCE1} >lmdb.pc
install -Dpm 0644 -t %{buildroot}%{_libdir}/pkgconfig lmdb.pc


%changelog
* Mon Nov 02 2020 luigiwalser <luigiwalser> 0.9.27-1.mga8
+ Revision: 1641702
- 0.9.27

* Wed Sep 02 2020 daviddavid <daviddavid> 0.9.26-1.mga8
+ Revision: 1620896
- new version: 0.9.26

* Fri Jul 10 2020 luigiwalser <luigiwalser> 0.9.25-1.mga8
+ Revision: 1604300
- 0.9.25 (partial resync with fedora)

* Wed Feb 26 2020 daviddavid <daviddavid> 0.9.24-3.mga8
+ Revision: 1550770
- provide a pkgconfig file

* Sat Feb 15 2020 umeabot <umeabot> 0.9.24-2.mga8
+ Revision: 1527761
- Mageia 8 Mass Rebuild

* Thu Jul 25 2019 buchan <buchan> 0.9.24-1.mga8
+ Revision: 1424167
- Update to 0.9.24

* Thu Dec 20 2018 buchan <buchan> 0.9.23-1.mga7
+ Revision: 1343856
- New version 0.9.23

* Sun Sep 23 2018 umeabot <umeabot> 0.9.22-2.mga7
+ Revision: 1299331
- Mageia 7 Mass Rebuild

* Thu Apr 05 2018 buchan <buchan> 0.9.22-1.mga7
+ Revision: 1215553
- New version 0.9.22

* Fri Sep 15 2017 cjw <cjw> 0.9.21-2.mga7
+ Revision: 1154211
- remove unused find_lang call

* Sun Jun 04 2017 buchan <buchan> 0.9.21-1.mga6
+ Revision: 1106582
- 0.9.21

* Tue Jan 10 2017 luigiwalser <luigiwalser> 0.9.19-1.mga6
+ Revision: 1080859
- 0.9.19
- update lmdb-make patch from fedora

* Fri Jun 10 2016 daviddavid <daviddavid> 0.9.18-2.mga6
+ Revision: 1021045
- do not provide liblmdb.so.0.0.0 from the devel subpackage (fixes mga#18679)

* Tue Feb 09 2016 buchan <buchan> 0.9.18-1.mga6
+ Revision: 952897
- New version 0.9.18

* Thu Dec 31 2015 buchan <buchan> 0.9.17-1.mga6
+ Revision: 917060
- New version 0.9.17
  Use github url for source

* Tue Aug 11 2015 neoclust <neoclust> 0.9.14-1.mga6
+ Revision: 863262
- imported package lmdb

